@@ -10,7 +10,7 @@ use Class::Std;
 use SOAP::WSDL::XSD::Typelib::Builtin::anySimpleType;
 use LWP::UserAgent;
 
-our $VERSION='2.00_13';
+our $VERSION='2.00_16';
 
 my %no_dispatch_of      :ATTR(:name<no_dispatch>);
 my %wsdl_of             :ATTR(:name<wsdl>);
@@ -34,6 +34,7 @@ my %serialize_options_of :ATTR(:default<()>);
 my %explain_options_of  :ATTR(:default<()>);
 
 my %client_of           :ATTR(:name<client>     :default<()>);
+my %keep_alive_of       :ATTR(:name<keep_alive> :default<0> );
 
 my %LOOKUP = (
   no_dispatch           => \%no_dispatch_of,
@@ -47,6 +48,7 @@ my %LOOKUP = (
   outputhash            => \%outputhash_of,
   portname              => \%portname_of,
   servicename           => \%servicename_of,
+  keep_alive            => \%keep_alive_of,
 );
 
 for my $method (keys %LOOKUP ) {
@@ -62,10 +64,12 @@ for my $method (keys %LOOKUP ) {
     };
 }
 
-{
+{   # just a BLOCK for scoping warnings.
+
     # we need to roll our own for supporting
     # SOAP::WSDL->new( key => value ) syntax, 
-    # like SOAP::Lite does
+    # like SOAP::Lite does. Class::Std enforces a single hash ref as
+    # parameters to new()
     no warnings qw(redefine);
     sub new {
         my $class = shift;
@@ -92,11 +96,14 @@ sub wsdlinit {
     my $ident = ident $self;
     my %opt = @_;
 
-    my $lwp = LWP::UserAgent->new();
+    my $lwp = LWP::UserAgent->new(
+        $keep_alive_of{ $ident } 
+        ? (keep_alive => 1)
+        : () 
+    );
     my $response = $lwp->get( $wsdl_of{ $ident } );
     croak $response->message() if ($response->code != 200);
 
-    # TODO: Port parser to expat and remove XML::LibXML dependency
     my $parser = SOAP::WSDL::Expat::WSDLParser->new();
     $parser->parse_string( $response->content() );
 
@@ -149,7 +156,7 @@ sub _wsdl_get_binding :PRIVATE {
     my $ident = ident $self;
     my $wsdl = $definitions_of{ $ident };
     my $port = $port_of{ $ident } || $self->_wsdl_get_port();
-    $binding_of{ $ident } = $wsdl->find_binding( $wsdl->_expand( $port->get_binding() ) )
+    $binding_of{ $ident } = $wsdl->find_binding( $port->expand( $port->get_binding() ) )
         or die "no binding found for ", $port->get_binding();
     return $binding_of{ $ident };
 } 
@@ -159,7 +166,7 @@ sub _wsdl_get_portType :PRIVATE {
     my $ident   = ident $self;
     my $wsdl    = $definitions_of{ $ident };
     my $binding = $binding_of{ $ident } || $self->_wsdl_get_binding();
-    $porttype_of{ $ident } = $wsdl->find_portType( $wsdl->_expand( $binding->get_type() ) )
+    $porttype_of{ $ident } = $wsdl->find_portType( $binding->expand( $binding->get_type() ) )
         or die "cannot find portType for " . $binding->get_type();
     return $porttype_of{ $ident };
 } 
@@ -200,15 +207,29 @@ sub _wsdl_init_methods :PRIVATE {
         # 3. get input message
         my $message = $wsdl->find_message( $ns, $localname )
           or die "Message {$ns}$localname not found in WSDL definition";
+
+        if (my $body=$binding_operation->first_input()->first_body()) {
+            if ($body->get_parts()) {
+                $method->{ parts } = [];        # make sure it's empty
+                my $message_part_ref = $message->get_part();
+                for my $name (split m{\s} , $body->get_parts() ) {
+                    $name =~s{ \A [^:]+: }{}x;  # throw away ns prefix
+                    # could probably made more efficient, but our lists are
+                    # usually quite short
+                    push @{ $method->{ parts } }, 
+                        grep { $_->get_name() eq $name } @{ $message_part_ref };
+                }
+            }   
+        }
+        $method->{ parts } ||= $message->get_part();
         
-        $method->{ parts } = $message->get_part();
 
         # rpc / encoded methods may have a namespace specified.
         # look it up and set it...
         $method->{ namespace } = $binding_operation 
             ? do { 
                 my $input = $binding_operation->first_input(); 
-                $input ? $input->get_namespace() : undef;  
+                $input ? $input->first_body()->get_namespace() : undef;  
             }
             : undef;
 
@@ -232,16 +253,23 @@ sub call {
     $self->_wsdl_init_methods() if not ($method_info_of{ $ident });
 
     my $client = $client_of{ $ident };
-    $client->set_proxy( $proxy_of{ $ident } || $port_of{ $ident }->get_location() );
+    
+    # pass-through keep_alive if we need it...
+    $client->set_proxy( $proxy_of{ $ident } 
+        || $port_of{ $ident }->first_address()->get_location(),
+        $keep_alive_of{ $ident } ? (keep_alive => 1) : (), 
+    );
+    
     $client->set_no_dispatch( $no_dispatch_of{ $ident } );
-
     $client->set_outputxml( $outputxml_of{ $ident } ? 1 : 0 );
 
+    # only load ::Deserializer::SOM if we really need to deserialize to SOM.
     # maybe we should introduce something like $output{ $ident } with a fixed 
     # set of values - m{^(TREE|HASH|XML|SOM)$}xms ?
     if ( ( ! $outputtree_of{ $ident } )
       && ( ! $outputhash_of{ $ident } ) 
-      && ( ! $outputxml_of{ $ident } ) ) {
+      && ( ! $outputxml_of{ $ident } ) 
+      && ( ! $no_dispatch_of{ $ident } ) ) {
         require SOAP::WSDL::Deserializer::SOM;
         $client->set_deserializer( SOAP::WSDL::Deserializer::SOM->new() );
     };
@@ -674,18 +702,21 @@ L<http://www.cpanforum.com/dist/SOAP-WSDL>
 There are many people out there who fostered SOAP::WSDL's developement. 
 I would like to thank them all (and apologize to all those I have forgotten).
 
-Giovanni S. Fois wrote a improved version of SOAP::WSDL (which eventually became v1.23)
+Giovanni S. Fois wrote a improved version of SOAP::WSDL (which eventually 
+became v1.23)
 
-Damian A. Martinez Gelabert, Dennis S. Hennen, Dan Horne, Peter Orvos, Mark Overmeer, 
-Jon Robens, Isidro Vila Verde and Glenn Wood spotted bugs and/or 
-suggested improvements in the 1.2x releases.
+David Bussenschutt, Damian A. Martinez Gelabert, Dennis S. Hennen, Dan Horne,
+Peter Orvos, Mark Overmeer, Jon Robens, Isidro Vila Verde and Glenn Wood 
+spotted bugs and/or suggested improvements in the 1.2x releases.
 
-Andreas 'ACID' Specht constantly asked for better performance.
+Andreas 'ac0v' Specht constantly asked for better performance.
+
+JT Justman provided some early feedback for the 2.xx pre-releases.
 
 Numerous people sent me their real-world WSDL files for testing. Thank you.
 
-Paul Kulchenko and Byrne Reese wrote and maintained SOAP::Lite and thus provided a 
-base (and counterpart) for SOAP::WSDL.
+Paul Kulchenko and Byrne Reese wrote and maintained SOAP::Lite and 
+thus provided a base (and counterpart) for SOAP::WSDL.
 
 =head1 LICENSE
 
@@ -700,10 +731,10 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 218 $
+ $Rev: 288 $
  $LastChangedBy: kutterma $
- $Id: WSDL.pm 218 2007-09-10 16:19:23Z kutterma $
- $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL.pm $
+ $Id: WSDL.pm 288 2007-09-29 19:34:20Z kutterma $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL.pm $
  
 =cut
 
