@@ -1,9 +1,9 @@
 package SOAP::WSDL::Base;
 use strict;
 use warnings;
-use Carp;
 use Class::Std::Storable;
 use List::Util qw(first);
+use Carp;
 
 my %id_of :ATTR(:name<id> :default<()>);
 my %name_of :ATTR(:name<name> :default<()>);
@@ -23,6 +23,16 @@ sub STORABLE_freeze_post :CUMULATIVE {};
 sub STORABLE_thaw_pre :CUMULATIVE {};
 sub STORABLE_thaw_post :CUMULATIVE { return $_[0] };
 
+sub _accept {
+    my $self = shift;
+    my $class = ref $self;
+    $class =~ s{ \A SOAP::WSDL:: }{}xms;
+    $class =~ s{ (:? :: ) }{_}gxms;
+    my $method = "visit_$class";
+    no strict qw(refs);
+    shift->$method( $self );
+}
+
 # unfortunately, AUTOMETHOD is SLOW.
 # Re-implement in derived package wherever speed is an issue...
 #
@@ -39,8 +49,6 @@ sub AUTOMETHOD {
         ## And we would have to check getters, too.
         ## Maybe do it the Conway way via the Symbol table...
         ## ... can is way slow...
-        # croak "no set accessor found for push_$subname"
-        #    if not ($self->can( $setter ));
         return sub {
             no strict qw(refs);
             my $old_value = $self->$getter();
@@ -54,6 +62,7 @@ sub AUTOMETHOD {
 
     # we're called as $obj->find_something($ns, $key)
     elsif ($subname =~s {^find_}{get_}xms) {
+        @values = @{ $values[0] } if ref $values[0] eq 'ARRAY';
         return sub {
             return first {
                 $_->get_targetNamespace() eq $values[0] &&
@@ -70,7 +79,7 @@ sub AUTOMETHOD {
             return $result_ref->[0];
         };
     }
-    croak "$subname not found in class " . (ref $self || $self);
+    confess "$subname not found in class " . (ref $self || $self) ;
 }
 
 sub init {
@@ -94,9 +103,10 @@ sub init {
             # TODO handle xmlns correctly - maybe via setting a prefix ?
             next;
         }
-    my $name = $value->{ LocalName };
-    my $method = "set_$name";
-        $self->$method( $value->{ Value } )	if ( $method );
+
+        my $name = $value->{ LocalName };
+        my $method = "set_$name";
+        $self->$method( $value->{ Value } );
     }
     return $self;
 }
@@ -113,12 +123,20 @@ sub to_typemap {
     return q{};
 }
 
-sub toClass {
-    my $self = shift;
-    warn 'toClass is deprecated and will be removed before reaching 2.01 - ' 
-        . 'use to_class instead (' . caller() . ')';
-    $self->to_class(@_);
+sub expand {
+    my ($self, , $qname) = @_;
+    my ($prefix, $localname) = split /:/, $qname;
+    my %ns_map = reverse %{ $self->get_xmlns() };
+    return ($ns_map{ $prefix }, $localname) if ($ns_map{ $prefix });
+    
+    if (my $parent = $self->get_parent()) {
+        return $parent->expand($qname);
+    }
+    die "unbound prefix $prefix found for $prefix:$localname";
 }
+sub _expand; 
+*_expand = \&expand;
+
 
 sub to_class {
     my $self = shift;
