@@ -4,8 +4,6 @@ use warnings;
 use Carp;
 
 use Class::Std::Storable;
-use LWP::UserAgent;
-use HTTP::Request;
 use Scalar::Util qw(blessed);
 
 use SOAP::WSDL::Factory::Deserializer;
@@ -13,11 +11,7 @@ use SOAP::WSDL::Factory::Serializer;
 use SOAP::WSDL::Factory::Transport;
 use SOAP::WSDL::Expat::MessageParser;
 
-our $VERSION = '2.00_14';
-
-# Package global for speed and memory savings.
-# But should be factored out into serializer/deserializer...
-my $PARSER;
+our $VERSION = '2.00_16';
 
 my %class_resolver_of   :ATTR(:name<class_resolver> :default<()>);
 my %no_dispatch_of      :ATTR(:name<no_dispatch>    :default<()>);
@@ -33,10 +27,6 @@ my %content_type_of     :ATTR(:name<content_type>   :default<text/xml; charset=u
 my %serializer_of       :ATTR(:name<serializer>     :default<()>);
 my %deserializer_of     :ATTR(:name<deserializer>   :default<()>);
 
-# TODO remove when preparing 2.01
-sub outputtree { warn 'outputtree is deprecated and'
-    . 'will be removed before reaching v2.01 !' }
-
 sub BUILD {
     my ($self, $ident, $attrs_of_ref) = @_;
 
@@ -216,6 +206,8 @@ sub call {
 
 1;
 
+__END__
+
 =pod
 
 =head1 NAME
@@ -355,12 +347,18 @@ SOAP::WSDL::Client and implementing something like
 You may even do this in a class factory - see L<wsdl2perl.pl> for creating 
 such interfaces.
 
-=head3 Debugging / Tracing
+=head1 Troubleshooting
 
-While SOAP::Lite features a global tracing facility, SOAP::WSDL::Client 
-allows to switch tracing on/of on a per-object base.
+=head2 Accessing protected web services
 
-See L<set_trace|set_trace> on how to enable tracing.
+Accessing protected web services is very specific for the transport 
+backend used.
+
+In general, you may pass additional arguments to the set_proxy method (or 
+a list ref of the web service address and any additional arguments to the 
+new method's I<proxy> argument).
+
+Refer to the appropriate transport module for documentation.
 
 =head1 LICENSE
 
@@ -375,10 +373,10 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 239 $
+ $Rev: 288 $
  $LastChangedBy: kutterma $
- $Id: Client.pm 239 2007-09-11 09:45:42Z kutterma $
- $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Client.pm $
+ $Id: Client.pm 288 2007-09-29 19:34:20Z kutterma $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Client.pm $
  
 =cut
 
