@@ -2,12 +2,33 @@ package SOAP::WSDL::Client::Base;
 use strict;
 use warnings;
 use base 'SOAP::WSDL::Client';
+use Scalar::Util qw(blessed);
+
+sub call {
+    my ($self, $method, $body, $header) = @_;
+    if (not blessed $body) {
+        my $class = $method->{ body }->{ parts }->[0];
+        eval "require $class" || die $@;
+        $body = $class->new($body); 
+    }
+    
+    # if we have a header
+    if (%{ $method->{ header } }) {
+        if (not blessed $header) {
+            my $class = $method->{ header }->{ parts }->[0];
+            eval "require $class" || die $@;
+            $header = $class->new($header); 
+        }
+    }
+    return $self->SUPER::call($method, $body, $header);  
+}
 
 sub __create_new {
   my ($package, %args_of) = @_;
   
   no strict qw(refs);
   
+  # TODO factor out and replace by generated START method
   *{ "$package\::new" } = sub {
       my $class = shift;
       my $self = $class->SUPER::new({
@@ -17,7 +38,6 @@ sub __create_new {
       bless $self, $class;
       return $self;
   }
-  
 }
 
 sub __create_methods {
@@ -93,9 +113,9 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 214 $
+ $Rev: 283 $
  $LastChangedBy: kutterma $
- $Id: Base.pm 214 2007-09-10 15:54:52Z kutterma $
- $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Client/Base.pm $
+ $Id: Base.pm 283 2007-09-27 19:06:29Z kutterma $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Client/Base.pm $
  
 =cut
