@@ -9,6 +9,7 @@ sub new {
     my ($class, $args) = @_;
     my $self = {
         class_resolver => $args->{ class_resolver },
+        strict => exists $args->{ strict } ? $args->{ strict } : 1,   
     };
     bless $self, $class;
     return $self;
@@ -17,67 +18,87 @@ sub new {
 sub class_resolver {
     my $self = shift;
     $self->{ class_resolver } = shift;
+    return;
 }
 
 sub _initialize {
     my ($self, $parser) = @_;
+    $self->{ parser } = $parser;
 
     delete $self->{ data };                     # remove potential old results
     
     my $characters;
+    #my @characters_from = ();
     my $current = undef;
-    my $ignore = [ 'Envelope', 'Body' ];        # top level elements to ignore
-    my $list = [];                              # node list
-    my $path = [];                              # current path 
-    my $skip = 0;                               # skip elements
+    my $list = [];                      # node list
+    my $path = [];                      # current path 
+    my $skip = 0;                       # skip elements
+    my $current_part = q{};             # are we in header or body ?
+
+    my $depth = 0;
+
+    my %content_check = $self->{strict} 
+        ? (
+            0 => sub {
+                    die "Bad top node $_[1]" if $_[1] ne 'Envelope';
+                    die "Bad namespace for SOAP envelope: " . $_[0]->recognized_string()
+                        if $_[0]->namespace($_[1]) ne 'http://schemas.xmlsoap.org/soap/envelope/';
+                    $depth++;
+                    return;            
+            },
+            1 => sub {
+                    $depth++;
+                    return;            
+            }
+        ) 
+        : ();
+
+    my $char_handler = sub {
+            # push @characters_from, $_[1] if $_[1] =~m{ [^s] }xms;
+            $characters .= $_[1] if $_[1] =~m{ [^\s] }xms;
+             
+            return;
+    };
 
     # use "globals" for speed
-    my ($_prefix, $_localname, $_element, $_method, 
-        $_class, $_parser, %_attrs) = ();
+    my ($_prefix, $_method, 
+        $_class) = ();
 
     no strict qw(refs);     
     $parser->setHandlers(
-        Start => sub {
-            ($_parser, $_element, %_attrs) = @_;
-            ($_prefix, $_localname) = split m{:}xms , $_element;
+        Start => sub {          
+            # my ($parser, $element, %_attrs) = @_;
+            # $depth = $parser->depth();
 
-            $_localname ||= $_element;          # for non-prefixed elements          
+            # call methods without using their parameter stack
+            # That's slightly faster than $content_check{ $depth }->()
+            # and we don't have to pass $_[1] to the method.
+            # Yup, that's dirty. 
+            return &{$content_check{ $depth }} if exists $content_check{ $depth }; 
+
+            push @{ $path }, $_[1];       # step down in path
+            return if $skip;               # skip inside __SKIP__
             
-            # ignore top level elements
-            if (@{ $ignore } && $_localname eq $ignore->[0]) {
-                CHECK_ENVELOPE: {
-                    last CHECK_ENVELOPE if $_localname ne 'Envelope';
-                    last CHECK_ENVELOPE if exists $_attrs{ 'xmlns' } 
-                      && $_attrs{ 'xmlns' } eq 'http://schemas.xmlsoap.org/soap/envelope/';
-                    last CHECK_ENVELOPE if $_attrs{ "xmlns:$_prefix"} 
-                      eq 'http://schemas.xmlsoap.org/soap/envelope/';
-                    die "Bad namespace for SOAP envelope: " . $parser->recognized_string();
-                }
-                shift @{ $ignore };
-                return;
-            }
-
-            push @{ $path }, $_localname;       # step down in path
-            return if $skip;                    # skip inside __SKIP__
-
             # resolve class of this element
             $_class = $self->{ class_resolver }->get_class( $path )
                 or die "Cannot resolve class for "
                     . join('/', @{ $path }) . " via " . $self->{ class_resolver };
 
-            # maybe write as "return $skip = join ... if (...)" ?
-            # would save a BLOCK...
-            return $skip = join('/', @{ $path }) if ($_class eq '__SKIP__');
+            if ($_class eq '__SKIP__') {
+                $skip = join('/', @{ $path });
+                $self->setHandlers( Char => undef );
+                return;
+            } 
              
             push @$list, $current;   # step down in tree ()remember current)
                 
-            $characters = q{};      # empty characters
+            $characters = q();      # empty characters
+            #@characters_from = ();
    
-            # Check whether we have a primitive - we implement them as classes
+            # Check whether we have a builtin - we implement them as classes
             # We could replace this with UNIVERSAL->isa() - but it's slow...
             # match is a bit faster if the string does not match, but WAY slower 
-            # if $class matches...
-                    
+            # if $class matches...              
             if (index $_class, 'SOAP::WSDL::XSD::Typelib::Builtin', 0 < 0) {           
                 # check wheter there is a non-empty ARRAY reference for $_class::ISA
                 # or a "new" method
@@ -90,65 +111,79 @@ sub _initialize {
                       or die $@;                        
             }
             
-            $current = $_class->new({ %_attrs });   # set new current object
+            $current = $_class->new({ @_[2..$#_] });   # set new current object
         
             # remember top level element
             exists $self->{ data } 
                 or ($self->{ data } = $current); 
+            $depth++;
+            return;
         },
         
-        Char => sub {
-            return if $skip;
-            $characters .= $_[1];
-        },
+        Char => $char_handler,
+        
+        End => sub {
         
-        End => sub {        
-            $_element = $_[1];
-
-            ($_prefix, $_localname) = split m{:}xms , $_element;          
-            $_localname ||= $_element;          # for non-prefixed elements            
-
             pop @{ $path };                     # step up in path
        
             if ($skip) {
-                return if $skip ne join '/', @{ $path }, $_localname;
+                return if $skip ne join '/', @{ $path }, $_[1];
                 $skip = 0;
+                $_[0]->setHandler( Char => $char_handler );
                 return;
             }
+
+            $depth--;
       
             # This one easily handles ignores for us, too...
-            return if not ref $$list[-1];
+            return if not ref $list->[-1];
     
             # set characters in current if we are a simple type
             # we may have characters in complexTypes with simpleContent,
             # too - maybe we should rely on the presence of characters ?
             # may get a speedup by defining a ident method in anySimpleType 
             # and looking it up via exists &$class::ident;
-            if ( $current->isa('SOAP::WSDL::XSD::Typelib::Builtin::anySimpleType') ) {
-                $current->set_value( $characters );
-            }
+#            if ( $current->isa('SOAP::WSDL::XSD::Typelib::Builtin::anySimpleType') ) {
+#                $current->set_value( $characters );
+#            }
             # currently doesn't work, as anyType does not implement value - 
             # maybe change ?
-#            $current->set_value( $characters ) if ($characters);
-        
+            $current->set_value( $characters ) if (length $characters);
+            #$current->set_value( join @characters_from ) if (@characters_from);
+            $characters = q{};
+#            undef @characters_from;
             # set appropriate attribute in last element
             # multiple values must be implemented in base class
-            $_method = "add_$_localname";
-            $$list[-1]->$_method( $current );
+            #$_method = "add_$_localname";
+            $_method = "add_$_[1]";
+            $list->[-1]->$_method( $current );
             
             $current = pop @$list;           # step up in object hierarchy...
+            return;
         }
     );
     return $parser;
 }
 
 sub parse {
-    $_[0]->_initialize( XML::Parser::Expat->new() )->parse( $_[1] );
+    eval { 
+        $_[0]->_initialize( 
+            XML::Parser::Expat->new(
+                Namespaces => 1
+                )
+            )->parse( $_[1] );
+        $_[0]->{ parser }->release();
+    };
+    $_[0]->{ parser }->xpcroak( $@ ) if $@;
     return $_[0]->{ data };     
 }
 
 sub parsefile {
-    $_[0]->_initialize( XML::Parser::Expat->new() )->parsefile( $_[1] );
+    eval { 
+        $_[0]->_initialize( XML::Parser::Expat->new(Namespaces => 1) )->parsefile( $_[1] ); 
+        $_[0]->{ parser }->release();
+    };
+    die $@, $_[1] if $@;
     return $_[0]->{ data };     
 }
 
@@ -218,9 +253,9 @@ This module may be used under the same terms as perl itself.
 
  $ID: $
 
- $LastChangedDate: 2007-09-10 18:19:23 +0200 (Mo, 10 Sep 2007) $
- $LastChangedRevision: 218 $
+ $LastChangedDate: 2007-09-27 21:06:29 +0200 (Don, 27 Sep 2007) $
+ $LastChangedRevision: 283 $
  $LastChangedBy: kutterma $
 
- $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Expat/MessageParser.pm $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Expat/MessageParser.pm $
 
