@@ -4,15 +4,26 @@ use warnings;
 use Class::Std::Storable;
 use base qw(SOAP::WSDL::Base);
 
+my %annotation_of   :ATTR(:name<annotation>     :default<()>);
 my %base_of         :ATTR(:name<base>           :default<()>);
 my %itemType_of     :ATTR(:name<itemType>       :default<()>);
 my %enumeration_of  :ATTR(:name<enumeration>    :default<()>);
 # is set to simpleContent/complexContent
-my %content_Model_of    :ATTR(:name<contentModel>   :default<()>);
+# my %content_model_of    :ATTR(:name<contentModel>   :default<()>);
 
+# TODO rename flavor to content_model to be consistent with the XML Schema
+# specs - though flavor is the cooler name..
 # set to restriction|list|union|enumeration
 my %flavor_of       :ATTR(:name<flavor>         :default<()>);
 
+# for simpleType containing atomic simple types
+my %type_of         :ATTR(:name<type>           :default<()>);
+
+sub get_simpleType; *get_simpleType = \&get_type;
+sub set_simpleType; *set_simpleType = \&set_type;
+
+sub get_variety; *get_variety = \&get_flavor;
+
 sub set_restriction {
     my $self = shift;
     my @attributes = @_;
@@ -28,8 +39,8 @@ sub set_list {
     my @attributes = @_;
     $self->set_flavor( 'list' );
     for (@attributes) {
-        next if (not $_->{ LocalName } eq 'type');
-        $self->set_base( $_->{ Value } );
+        next if (not $_->{ LocalName } eq 'itemType');
+        $self->set_itemType( $_->{ Value } );
     }
 }
 
@@ -99,55 +110,8 @@ sub _serialize_single {
     return $xml;
 }
 
-sub explain {
-	my ($self, $opt, $name ) = @_;
-	$opt->{ indent } = q{} if not defined $opt->{ indent };
-	return "$opt->{ indent }'$name' => \$someValue,\n"
-}
-
 sub _check_value {
 	my $self = shift;
 }
 
-# TODO: implement to_class based on template...
-
-sub to_class {
-    my $self = shift;
-    my $opt = shift;
-    my $class_prefix = $opt->{ type_prefix };
-    my $name = $opt->{name} || $self->get_name();
-    my $flavor = $self->get_flavor() eq 'list' 
-        ? 'SOAP::WSDL::XSD::Typelib::Builtin::list'
-        : $self->get_flavor() eq 'restriction' 
-            ? 'SOAP::WSDL::XSD::Typelib::SimpleType::restriction'
-            : q{};
-    my $base = $self->get_base();
-    my $targetNamespace = $self->get_targetNamespace;
-    my ($prefix, $localname) = split /:/, $base;
-    my %ns_map = reverse %{ $opt->{ wsdl }->get_xmlns() };
-    $base = ($ns_map{ $prefix} eq 'http://www.w3.org/2001/XMLSchema') 
-        ? "SOAP::WSDL::XSD::Typelib::Builtin::$localname"
-        : "$opt->{prefix}::$localname";
-    
-    my $code =<<"EOT";
-package $class_prefix::$name;
-use strict;
-use Class::Std::Storable;
-use SOAP::WSDL::XSD::Typelib::Builtin;
-use SOAP::WSDL::XSD::Typelib::SimpleType;
-use base qw(
-    SOAP::WSDL::XSD::Typelib::SimpleType
-    $flavor
-    $base
-);
-
-1;
-
-sub get_xmlns { '$targetNamespace' }
-
-EOT
-
-    return $code;
-}
-
 1;
