@@ -13,15 +13,23 @@ my %value_of :ATTR(:get<value> :init_arg<value> :default<()>);
 # and we don't need to return the last value...
 sub set_value { $value_of{ ident $_[0] } = $_[1] }
 
+# use $_[n] for speed.
+# This is less readable, but notably faster.
+#
+# use postfix-if for speed. This is slightly faster, as it saves 
+# perl from creating a pad (variable context).
+#
+# The methods below may get called zillions of times, so 
+# every little statement matters...
+
 sub serialize {
-    my ($self, $opt) = @_;
-    my $ident = ident $self;
-    $opt ||= {};
-    return $self->start_tag({ %$opt, nil => 1})
-        if not defined $value_of{ $ident };
-    return join q{}, $self->start_tag($opt, $value_of{ $ident })
+    no warnings qw(uninitialized);
+    my $ident = ident $_[0];
+    $_[1]->{ nil } = 1 if not defined $value_of{ $ident };
+    return join q{}
+        , $_[0]->start_tag($_[1], $value_of{ $ident })
         , $value_of{ $ident }
-        , $self->end_tag($opt);
+        , $_[0]->end_tag($_[1]); 
 }
 
 # TODO disallow serializing !
