@@ -10,6 +10,8 @@ use Class::Std::Storable;
 
 use base qw(SOAP::WSDL::XSD::Typelib::Builtin::anyType);
 
+our $VERSION = '2.00_16';
+
 my %ELEMENTS_FROM;
 my %ATTRIBUTES_OF;
 my %CLASSES_OF;
@@ -17,17 +19,10 @@ my %CLASSES_OF;
 # STORABLE_ methods for supporting Class::Std::Storable.
 # We could also handle them via AUTOMETHOD,
 # but AUTOMETHOD should always croak...
-sub STORABLE_freeze_pre {  
-}
-
-sub STORABLE_freeze_post {  
-}
-
-sub STORABLE_thaw_pre {  
-}
-
-sub STORABLE_thaw_post {  
-}
+sub STORABLE_freeze_pre {}
+sub STORABLE_freeze_post {}
+sub STORABLE_thaw_pre {}
+sub STORABLE_thaw_post {}
 
 # for error reporting. Eases working with data objects...
 sub AUTOMETHOD {
@@ -50,49 +45,56 @@ sub _factory {
 
     no strict qw(refs);
     no warnings qw(redefine); 
-    while (my ($name, $attribute_ref) = each %{ $ATTRIBUTES_OF{ $class } } )
-    {
+    while (my ($name, $attribute_ref) = each %{ $ATTRIBUTES_OF{ $class } } ) {
         my $type = $CLASSES_OF{ $class }->{ $name }
-            or die "No class given for $name";
+            or croak "No class given for $name";
 
         # require all types here
         $type->isa('UNIVERSAL')
             or eval "require $type" 
                 or croak $@;
 
-        # check now, so we don't need to do it later...
+        # check now, so we don't need to do it later.
+        # $is_list is used in the methods created. Filling it now means 
+        # we don't have to check it every time the method is called, but 
+        # can just use $is_list, which will hold the value assigned to 
+        # it when the method was created.
         my $is_list = $type->isa('SOAP::WSDL::XSD::Typelib::Builtin::list');
-
+        
+        #  The set_$name method below looks rather weird, 
+        # but is optimized for performance.
+        #
+        #  We could use sub calls for sure, but these are much slower. And 
+        # the logic is not that easy:
+        #
+        #  we accept:
+        #  a) objects
+        #  b) scalars            
+        #  c) list refs
+        #  d) hash refs
+        #  e) mixed stuff of all of the above, so we have to set our child to 
+        #    a) value if it's an object
+        #    b) New object of expected class with value for simple values
+        #    c 1) New object with value for list values and list type
+        #    c 2) List ref of new objects with value for list values and 
+        #         non-list type
+        #    c + e 1) List ref of objects for list values (list of objects) 
+        #             and non-list type
+        #    c + e 2) List ref of new objects for list values (list of hashes) 
+        #             and non-list type where the hash ref is passed to new as 
+        #             argument        
+        #    d) New object with values passed to new for HASH references
+        #
+        #  We throw an error on
+        #  a) list refs of list refs - don't know what to do with this (maybe 
+        #     use for lists of list types ?)
+        #  b) wrong object types
+        #  c) non-blessed non-ARRAY/HASH references - if you can define semantics 
+        #     for GLOB or SCALAR references, feel free to add them.
+        #  d) we should also die for non-blessed non-ARRAY/HASH references in 
+        #     lists but don't do yet - oh my ! 
+        
         *{ "$class\::set_$name" } = sub  {
-            # my ($self, $value) = @_;
-
-#  The structure below looks rather weird, but is optimized for performance.
-#
-#  We could use sub calls for sure, but these are much slower. And the logic 
-#  is not that easy:
-#
-#  we accept:
-#  a) objects
-#  b) scalars            
-#  c) list refs
-#  d) hash refs
-#  e) mixed stuff of all of the above, so we have to set our element to 
-#  a) value if it's an object
-#  b) New object of expected class with value for simple values
-#  c 1) New object with value for list values and list type
-#  c 2) List ref of new objects with value for list values and non-list type
-#  c + e 1) List ref of objects for list values (list of objects) and non-list type
-#  c + e 2) List ref of new objects for list values (list of hashes) and non-list type
-#  where the hash ref is passed to new as argument        
-#  d) New object with values passed to new for HASH references
-#
-#  We throw an error on
-#  a) list refs of list refs - don't know what to do with this (maybe use for lists of list types ?)
-#  b) wrong object types
-#  c) non-blessed non-ARRAY/HASH references - if you can define semantics 
-#  for GLOB references, feel free to add them.
-#  d) we should also die for non-blessed non-ARRAY/HASH references in lists but don't do yet - oh my ! 
-
             my $is_ref = ref $_[1];
             $attribute_ref->{ ident $_[0] } = ($is_ref) 
                 ? $is_ref eq 'ARRAY' 
@@ -232,20 +234,49 @@ __END__
 
 =head1 NAME
 
-SOAP::WSDL::XSD::Typelib::ComplexType - complexType base class
+SOAP::WSDL::XSD::Typelib::ComplexType - Base class for complexType node classes
 
 =head1 Subclassing
 
+To subclass, write a package like this:
+
  package MyComplexType;
  use Class::Std::Storable
  use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);
  
+ # we only need the :get attribute qualifier.
+ # set and init_arg are automatically created by 
+ # SOAP::WSDL::XSD::Typelib::ComplexType
+ my %first_attr_of   :ATTR(:get<first_attr>  :default<()>);
+ my %second_attr_of  :ATTR(:get<second_attr> :default<()>);
+ my %third_attr_of   :ATTR(:get<third_attr>  :default<()>);
+ 
+ # the order of elements in a complexType
+ my @elements_from = qw(first_attr second_attr third_attr);
+ 
+ # references to the private hashes
+ my %attribute_of = (
+    first_attr  => \%first_attr_of,
+    second_attr => \%second_attr_of,
+    third_attr  => \%third_attr_of,
+ );
+ 
+ # classes_of: Classes the child elements should be of
+ my %classes_of = (
+    first_attr  => 'My::FirstElement',
+    second_attr => 'My::SecondElement',
+    third_attr  => 'My::ThirdElement',
+ );
+ 
+ # call _factory 
  __PACKAGE__->_factory(
     \@elements_from,
     \%attributes_of,
     \%classes_of 
  );
 
+ 1;
+
 When subclassing, the following methods are created in the subclass:
 
 =head2 new
@@ -287,9 +318,11 @@ Examples:
      MyThirdName => [ $object1, $object2 ],
  });
 
-To be correct, SOAP::WSDL::XSD::Typelib::ComplexType will create a START 
-method, not new() - but new() will be created from Class::Std::Storable and 
-behave like stated above.
+The new() method from Class::Std will be overridden, so you should not rely 
+on it's behaviour. 
+
+Your START and BUILD methods are called, but the class' inheritance tree is 
+not traversed.
 
 =head2 set_FOO
 
@@ -335,15 +368,23 @@ No facets are implemented yet.
 
 =back
 
+=head1 LICENSE
+
+Copyright 2004-2007 Martin Kutter.
+
+This file is part of SOAP-WSDL. You may distribute/modify it under 
+the same terms as perl itself
+
 =head1 AUTHOR
 
-Replace whitespace by @ in e-mail address.
+Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
- Martin Kutter E<gt>martin.kutter fen-net.deE<lt>
-
-=head1 COPYING
-
-This library is free software, you may distribute/modify it under the
-same terms as perl itself
+=head1 REPOSITORY INFORMATION
 
+ $Rev: 270 $
+ $LastChangedBy: kutterma $
+ $Id: ComplexType.pm 270 2007-09-20 21:55:36Z kutterma $
+ $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/XSD/Typelib/ComplexType.pm $
+ 
 =cut
+
